@@ -17,6 +17,8 @@ class State(local):
 
 def get_buffer(path, options):
     cls = import_string(path)
+    if cls is None:
+        raise ImportError('Unable to find module %s' % path)
     return cls(**options)
 
 buffer = get_buffer(settings.BUFFER, settings.BUFFER_OPTIONS)
