@@ -39,14 +39,11 @@ to_json = register.filter(to_json)
 @register.filter
 def pprint(value, break_after=10):
     """
-    A wrapper around pprint.pprint -- for debugging, really.
-
     break_after is used to define how often a <span> is
     inserted (for soft wrapping).
     """
-    from pprint import pformat
 
-    value = pformat(value).decode('utf-8', 'replace')
+    value = unicode(value).decode('utf-8', 'replace')
     return mark_safe(u'<span></span>'.join(
         [escape(value[i:(i + break_after)]) for i in xrange(0, len(value), break_after)]
     ))
@@ -73,11 +70,6 @@ def as_sorted(value):
     return sorted(value)
 
 
-@register.filter
-def is_dict(value):
-    return isinstance(value, dict)
-
-
 @register.filter
 def small_count(v):
     z = [
@@ -355,3 +347,37 @@ def github_button(user, repo):
         'user': user,
         'repo': repo,
     }
+
+
+@register.inclusion_tag('sentry/partial/data_values.html')
+def render_values(value, threshold=5, collapse_to=3):
+    is_dict = isinstance(value, dict)
+    context = {
+        'is_dict': is_dict,
+        'threshold': threshold,
+        'collapse_to': collapse_to,
+    }
+
+    if is_dict:
+        value = sorted(value.iteritems())
+        value_len = len(value)
+        over_threshold = value_len > threshold
+        if over_threshold:
+            context.update({
+                'over_threshold': over_threshold,
+                'hidden_values': value_len - collapse_to,
+                'value_before_expand': value[:collapse_to],
+                'value_after_expand': value[collapse_to:],
+            })
+        else:
+            context.update({
+                'over_threshold': over_threshold,
+                'hidden_values': 0,
+                'value_before_expand': value,
+                'value_after_expand': [],
+            })
+
+    else:
+        context['value'] = value
+
+    return context
