@@ -56,7 +56,10 @@ class EmailAuthBackend(ModelBackend):
             else:
                 return None
 
-        if user.check_password(password):
-            return user
+        try:
+            if user.check_password(password):
+                return user
+        except ValueError:
+            return None
 
         return None
